@@ -471,7 +471,8 @@ class AIOUnifiScanner:
             response_list[source_ip] = replace(
                 device,
                 platform=device.platform or short_name,
-                hostname=device.hostname or system.get("name").replace(" ", "-"),
+                hostname=device.hostname
+                or (system.get("name") or "").replace(" ", "-"),
                 hw_addr=device.hw_addr or (_format_mac(mac) if mac else None),
                 direct_connect_domain=system.get("directConnectDomain"),
                 is_sso_enabled=system.get("isSsoEnabled"),
